package
Version:
v0.0.0-...-1f1a93d
Opens a new window with list of versions in this module.
Published: May 13, 2026
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func HasChildModeFlag() bool
HasChildModeFlag 检查是否有 --multiple 参数
func RunChildMode() error
RunChildMode 运行子进程模式(公开接口)
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.