Documentation
¶
Overview ¶
NemesisBot - AI agent License: MIT Copyright (c) 2026 NemesisBot contributors
Index ¶
- func Debug(message string)
- func DebugC(component string, message string)
- func DebugCF(component string, message string, fields map[string]interface{})
- func DebugF(message string, fields map[string]interface{})
- func DisableConsole()
- func DisableFileLogging()
- func DisableLogging()
- func EnableConsole()
- func EnableFileLogging(filePath string) error
- func EnableLogging()
- func Error(message string)
- func ErrorC(component string, message string)
- func ErrorCF(component string, message string, fields map[string]interface{})
- func ErrorF(message string, fields map[string]interface{})
- func Fatal(message string)
- func FatalC(component string, message string)
- func FatalCF(component string, message string, fields map[string]interface{})
- func FatalF(message string, fields map[string]interface{})
- func Info(message string)
- func InfoC(component string, message string)
- func InfoCF(component string, message string, fields map[string]interface{})
- func InfoF(message string, fields map[string]interface{})
- func IsConsoleEnabled() bool
- func IsLoggingEnabled() bool
- func SetLevel(level LogLevel)
- func SetLogHook(hook LogHook)
- func Warn(message string)
- func WarnC(component string, message string)
- func WarnCF(component string, message string, fields map[string]interface{})
- func WarnF(message string, fields map[string]interface{})
- type LogEntry
- type LogHook
- type LogLevel
- type Logger
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DisableFileLogging ¶
func DisableFileLogging()
func EnableFileLogging ¶
func IsConsoleEnabled ¶
func IsConsoleEnabled() bool
IsConsoleEnabled returns whether console output is enabled
func IsLoggingEnabled ¶
func IsLoggingEnabled() bool
IsLoggingEnabled returns whether logging is enabled
func SetLogHook ¶
func SetLogHook(hook LogHook)
SetLogHook sets an optional callback that is invoked (asynchronously) for each log entry.
Types ¶
type LogHook ¶
type LogHook func(entry LogEntry)
LogHook is a callback function invoked for each log entry. Used to bridge logger output to SSE EventHub for Dashboard real-time updates.
Click to show internal directories.
Click to hide internal directories.